@@ -1,6 +1,5 @@
 # coding=utf-8
-""" Communities module
-"""
+"""Communities module."""
 from __future__ import absolute_import
 
 from abilian.sbe.extension import sbe
@@ -13,7 +12,9 @@ def register_plugin(app):
     from . import events  # noqa
 
     from .views import communities
+
     app.register_blueprint(communities)
 
     from . import search
+
     search.init_app(app)
