@@ -1,16 +1,31 @@
 # coding=utf-8
 
-from __future__ import absolute_import, print_function
-
-from flask import current_app, g, url_for
-from flask_login import current_user
+from __future__ import absolute_import, print_function, unicode_literals
 
 from abilian.i18n import _l
+from abilian.services import get_service
 from abilian.services.security import Admin
 from abilian.web.action import Action, FAIcon, ModalActionMixin, actions
+from flask import g, request, url_for
+from flask_login import current_user
 
 
 class ForumAction(Action):
+    def is_current(self):
+        return request.path == self.url()
+
+    def is_filtered(self):
+        filter_keys = ["today", "month", "year", "week"]
+        current_url = request.path.split("/")
+        filter = current_url[-1].strip()
+
+        if filter not in filter_keys:
+            return False
+
+        if self.url() == "#filter":
+            return True
+
+        return False
 
     def url(self, context=None):
         if self._url or self.endpoint:
@@ -20,24 +35,23 @@ class ForumAction(Action):
 
 
 class ThreadAction(ForumAction):
-
     def pre_condition(self, context):
-        thread = actions.context.get('object')
+        thread = actions.context.get("object")
         return not not thread
 
 
 def is_admin(context):
-    svc = current_app.services['security']
-    return svc.has_role(current_user, Admin, object=context.get('object'))
+    security = get_service("security")
+    return security.has_role(current_user, Admin, object=context.get("object"))
 
 
 def is_in_thread(context):
-    thread = context.get('object')
+    thread = context.get("object")
     return not thread
 
 
 def is_closed(context):
-    thread = context.get('object')
+    thread = context.get("object")
     return thread.closed
 
 
@@ -49,7 +63,7 @@ class ForumModalAction(ModalActionMixin, ThreadAction):
     pass
 
 
-_close_template_action = u'''
+_close_template_action = """
 <form method="POST" action="{{ url }}" encoding="multipart/form-data">
   {{ csrf.field() }}
   <button type="submit" class="btn btn-link" name="action"
@@ -58,54 +72,47 @@ _close_template_action = u'''
     {{ action.title }}
   </button>
 </form>
-'''
+"""
 
 _actions = (
+    ForumAction("forum:global", "index", _l("Recent conversations")),
+    ForumAction("forum:global", "index/<string:filter>", _l("Top"), url="#filter"),
+    ForumAction("forum:global", "archives", _l("Archives")),
     ForumAction(
-        'forum:global',
-        'new_thread',
-        _l(u'Start a new conversation'),
-        icon='plus'),
-    ForumAction(
-        'forum:global', 'index', _l(u'Recent conversations'), icon='list'),
-    ForumAction(
-        'forum:global', 'archives', _l(u'Archives'), icon='calendar'),
-    ForumAction(
-        'forum:global',
-        'attachments',
-        _l(u'Attachments'),
-        icon='file',
-        condition=is_in_thread),
+        "forum:global", "attachments", _l("Attachments"), condition=is_in_thread
+    ),
+    ForumAction("forum:global", "new_thread", _l("New conversation"), icon="plus"),
     ForumModalAction(
-        'forum:thread',
-        'delete',
-        _l(u'Delete'),
+        "forum:thread",
+        "delete",
+        _l("Delete"),
         condition=lambda ctx: is_admin(ctx) and not_closed(ctx),
-        url='#modal-delete',
-        icon='trash'),
+        url="#modal-delete",
+        icon="trash",
+    ),
     #
     ThreadAction(
-        'forum:thread',
-        'close',
-        _l('Close thread'),
-        url='close',
+        "forum:thread",
+        "close",
+        _l("Close thread"),
+        url="close",
         template_string=_close_template_action,
         condition=lambda ctx: is_admin(ctx) and not_closed(ctx),
-        icon=FAIcon('lock')),
+        icon=FAIcon("lock"),
+    ),
     ThreadAction(
-        'forum:thread',
-        'reopen',
-        _l('Re-open thread'),
-        url='close',
+        "forum:thread",
+        "reopen",
+        _l("Re-open thread"),
+        url="close",
         template_string=_close_template_action,
         condition=lambda ctx: is_admin(ctx) and is_closed(ctx),
-        icon=FAIcon('unlock')),
+        icon=FAIcon("unlock"),
+    ),
     ThreadAction(
-        'forum:thread',
-        'attachments',
-        _l(u'Attachments'),
-        url='attachments',
-        icon='file'),)
+        "forum:thread", "attachments", _l("Attachments"), url="attachments", icon="file"
+    ),
+)
 
 
 def register_actions(state):
