@@ -1,52 +1,50 @@
 # coding=utf-8
-"""
-"""
+""""""
 from __future__ import absolute_import, print_function, unicode_literals
 
 import bleach
-from wtforms import BooleanField, StringField, TextAreaField
-
 from abilian.i18n import _l
 from abilian.web.forms import Form, RichTextWidget
 from abilian.web.forms.fields import FileField
 from abilian.web.forms.filters import strip
-from abilian.web.forms.validators import optional, required
+from abilian.web.forms.validators import Length, optional, required
+from wtforms import BooleanField, StringField, TextAreaField
 
 ALLOWED_TAGS = [
-    'a',
-    'abbr',
-    'acronym',
-    'b',
-    'blockquote',
-    'br',
-    'code',
-    'em',
-    'i',
-    'li',
-    'ol',
-    'strong',
-    'ul',
-    'h1',
-    'h2',
-    'h3',
-    'h4',
-    'h5',
-    'h6',
-    'p',
-    'u',
-    'img',
+    "a",
+    "abbr",
+    "acronym",
+    "b",
+    "blockquote",
+    "br",
+    "code",
+    "em",
+    "i",
+    "li",
+    "ol",
+    "strong",
+    "ul",
+    "h1",
+    "h2",
+    "h3",
+    "h4",
+    "h5",
+    "h6",
+    "p",
+    "u",
+    "img",
 ]
 
 ALLOWED_ATTRIBUTES = {
-    '*': ['title'],
-    'p': ['style'],
-    'a': ['href', 'title'],
-    'abbr': ['title'],
-    'acronym': ['title'],
-    'img': ['src', 'alt', 'title'],
+    "*": ["title"],
+    "p": ["style"],
+    "a": ["href", "title"],
+    "abbr": ["title"],
+    "acronym": ["title"],
+    "img": ["src", "alt", "title"],
 }
 
-ALLOWED_STYLES = ['text-align',]
+ALLOWED_STYLES = ["text-align"]
 
 WIDGET_ALLOWED = {}
 for attr in ALLOWED_TAGS:
@@ -58,7 +56,8 @@ for attr in ALLOWED_TAGS:
 # instantiate this one before PostForm fields, so that it is listed first
 # when Threadform is displayed
 _TITLE_FIELD = StringField(
-    label=_l("Title"), filters=(strip,), validators=[required()])
+    label=_l("Title"), filters=(strip,), validators=[required(), Length(max=150)]
+)
 
 
 class BasePostForm(Form):
@@ -66,9 +65,11 @@ class BasePostForm(Form):
         label=_l("Message"),
         widget=RichTextWidget(allowed_tags=WIDGET_ALLOWED),
         filters=(strip,),
-        validators=[required()])
+        validators=[required()],
+    )
     attachments = FileField(
-        label=_l('Attachments'), multiple=True, validators=[optional()])
+        label=_l("Attachments"), multiple=True, validators=[optional()]
+    )
 
     def validate_message(self, field):
         field.data = bleach.clean(
@@ -76,7 +77,8 @@ class BasePostForm(Form):
             tags=ALLOWED_TAGS,
             attributes=ALLOWED_ATTRIBUTES,
             styles=ALLOWED_STYLES,
-            strip=True)
+            strip=True,
+        )
 
 
 class PostForm(BasePostForm):
@@ -89,7 +91,8 @@ class ThreadForm(PostForm):
 
 class PostEditForm(BasePostForm):
     reason = StringField(
-        label=_l('Reason'),
-        description=_l('Description of your edit'),
+        label=_l("Reason"),
+        description=_l("Description of your edit"),
         filters=(strip,),
-        validators=(optional(),))
+        validators=(optional(),),
+    )
