@@ -1,6 +1,5 @@
 # coding=utf-8
-"""
-"""
+""""""
 from __future__ import absolute_import
 
 import jinja2
@@ -10,5 +9,5 @@ from .panels.sbe_notifications import SbeNotificationsPanel
 
 
 def register_plugin(app):
-    app.register_jinja_loaders(jinja2.PackageLoader(__name__, 'templates'))
+    app.register_jinja_loaders(jinja2.PackageLoader(__name__, "templates"))
     preferences.register_panel(SbeNotificationsPanel(), app)
