@@ -1,3 +1,7 @@
+# coding=utf-8
+from __future__ import absolute_import
+
+
 def register_plugin(app):
     from .views import wiki
     from .actions import register_actions
