@@ -1,10 +1,11 @@
 # coding=utf-8
-"""
-"""
-from __future__ import absolute_import, print_function
+""""""
+from __future__ import absolute_import, print_function, unicode_literals
 
 from datetime import datetime
 
+from abilian.core.entities import SEARCHABLE, Entity, db
+from abilian.core.models.subjects import User
 from flask import g
 from sqlalchemy import Column, DateTime, ForeignKey, Integer, Unicode, \
     UnicodeText, UniqueConstraint
@@ -12,47 +13,47 @@ from sqlalchemy.event import listens_for
 from sqlalchemy.ext.hybrid import hybrid_property
 from sqlalchemy.orm import backref, relationship
 
-from abilian.core.entities import SEARCHABLE, Entity, db
-from abilian.core.models.subjects import User
 from abilian.sbe.apps.communities.models import Community, CommunityIdColumn, \
     community_content
 from abilian.sbe.apps.documents.models import BaseContent
 
 from . import markup
 
-__all__ = ['WikiPage']
+__all__ = ["WikiPage"]
 
 
 @community_content
 class WikiPage(Entity):
-    __tablename__ = 'wiki_page'
+    __tablename__ = "wiki_page"
 
     # : The title for this page
-    _title = Column('title', Unicode(200), nullable=False, index=True)
+    _title = Column("title", Unicode(200), nullable=False, index=True)
 
     community_id = CommunityIdColumn()
     #: The community this page belongs to
     community = relationship(
         Community,
         primaryjoin=(community_id == Community.id),
-        backref=backref(
-            "wiki", cascade="all, delete-orphan"))
+        backref=backref("wiki", cascade="all, delete-orphan"),
+    )
 
     #: The body, using some markup language (Markdown for now)
     body_src = Column(
         UnicodeText,
-        default=u"",
+        default="",
         nullable=False,
-        info=SEARCHABLE | dict(index_to=('text',)))
+        info=SEARCHABLE | {"index_to": ("text",)},
+    )
 
-    __table_args__ = (UniqueConstraint('title', 'community_id'),)
+    __table_args__ = (UniqueConstraint("title", "community_id"),)
 
-    def __init__(self, title=u"", body_src=u"", message=u"", *args, **kwargs):
+    def __init__(self, title="", body_src="", message="", *args, **kwargs):
         Entity.__init__(self, *args, **kwargs)
         self.title = title
         self.create_revision(body_src, message)
 
-    # title is defined has an hybrid property to allow name <-> title sync (2 way)
+    # title is defined has an hybrid property to allow name <-> title sync (2
+    # way)
     @hybrid_property
     def title(self):
         return self._title
@@ -65,7 +66,7 @@ class WikiPage(Entity):
         if self.name != title:
             self.name = title
 
-    def create_revision(self, body_src, message=u""):
+    def create_revision(self, body_src, message=""):
         revision = WikiPageRevision()
         if self.revisions:
             revision.number = max(r.number for r in self.revisions) + 1
@@ -78,10 +79,11 @@ class WikiPage(Entity):
 
     @property
     def last_revision(self):
-        return WikiPageRevision.query\
-            .filter(WikiPageRevision.page == self)\
-            .order_by(WikiPageRevision.number.desc())\
+        return (
+            WikiPageRevision.query.filter(WikiPageRevision.page == self)
+            .order_by(WikiPageRevision.number.desc())
             .first()
+        )
 
     @property
     def body_html(self):
@@ -89,15 +91,16 @@ class WikiPage(Entity):
         return html
 
         # TODO: remove Javascript from content
-        #return bleach.clean(html, strip=True)
+        # return bleach.clean(html, strip=True)
 
 
 @listens_for(WikiPage.name, "set", active_history=True)
 def _wiki_sync_name_title(entity, new_value, old_value, initiator):
-    """
-    Synchronize wikipage name -> title.
-    wikipage.title -> name is done via hybrid_property, avoiding infinite
-    loop (since "set" is received before attribute has received value)
+    """Synchronize wikipage name -> title.
+
+    wikipage.title -> name is done via hybrid_property, avoiding
+    infinite loop (since "set" is received before attribute has received
+    value)
     """
     if entity.title != new_value:
         entity.title = new_value
@@ -105,8 +108,8 @@ def _wiki_sync_name_title(entity, new_value, old_value, initiator):
 
 
 class WikiPageRevision(db.Model):
-    __tablename__ = 'wiki_page_revision'
-    __table_args__ = (UniqueConstraint('page_id', 'number'),)
+    __tablename__ = "wiki_page_revision"
+    __table_args__ = (UniqueConstraint("page_id", "number"),)
 
     # : Some primary key just in case
     id = Column(Integer, primary_key=True)
@@ -115,17 +118,17 @@ class WikiPageRevision(db.Model):
     created_at = Column(DateTime, default=datetime.utcnow)
 
     #: The page this revision belongs to
-    page = relationship(WikiPage, backref='revisions')
+    page = relationship(WikiPage, backref="revisions")
     page_id = Column(ForeignKey(WikiPage.id))
 
     #: The revision number
     number = Column(Integer, nullable=False)
 
     #: The body, using some markup language (Markdown for now)
-    body_src = Column(UnicodeText, default=u"", nullable=False)
+    body_src = Column(UnicodeText, default="", nullable=False)
 
     #: Commit message
-    message = Column(UnicodeText, default=u"", nullable=False)
+    message = Column(UnicodeText, default="", nullable=False)
 
     #: The author of this revision
     author = relationship(User)
@@ -135,15 +138,17 @@ class WikiPageRevision(db.Model):
 class WikiPageAttachment(BaseContent):
     __tablename__ = None  # type: str
     __indexable__ = False
-    __mapper_args__ = {'polymorphic_identity': 'wikipage_attachment'}
-    sbe_type = 'wikipage:attachment'
+    __mapper_args__ = {"polymorphic_identity": "wikipage_attachment"}
+    sbe_type = "wikipage:attachment"
 
     _wikipage_id = Column(Integer, ForeignKey(WikiPage.id), nullable=True)
     wikipage = relationship(
         WikiPage,
         primaryjoin=(_wikipage_id == WikiPage.id),
         backref=backref(
-            'attachments',
-            lazy='select',
-            order_by='WikiPageAttachment.name',
-            cascade='all, delete-orphan'))
+            "attachments",
+            lazy="select",
+            order_by="WikiPageAttachment.name",
+            cascade="all, delete-orphan",
+        ),
+    )
